<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en_US">
<context>
    <name>ArrowToolOptionsBox</name>
    <message>
        <source>Pick:</source>
        <translation>拾取:</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>左右:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>上下:</translation>
    </message>
    <message>
        <source>Z:</source>
        <translation>纵深:</translation>
    </message>
    <message>
        <source>SO:</source>
        <translation>堆栈顺序:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>旋转</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <source>Global:</source>
        <translation>全局:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>水平:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>垂直:</translation>
    </message>
    <message>
        <source>Maintain:</source>
        <translation>保持:</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>切变</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">中心点</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="vanished">锁定</translation>
    </message>
    <message>
        <source>(</source>
        <translation>(</translation>
    </message>
    <message>
        <source>)</source>
        <translation>)</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>中心位置</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>位置:</translation>
    </message>
    <message>
        <source>Rotation:</source>
        <translation>旋转:</translation>
    </message>
    <message>
        <source>Table</source>
        <translation>动画台</translation>
    </message>
</context>
<context>
    <name>BrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">粗细</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation type="vanished">硬度:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation type="vanished">精度:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation type="vanished">选择性</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="vanished">预设:</translation>
    </message>
    <message>
        <source>Break Sharp Angles</source>
        <translation type="vanished">断开尖角</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation type="vanished">铅笔模式</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">压力灵敏度</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation type="vanished">端点</translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="vanished">连接</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation type="vanished">斜接比例:</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="vanished">大小</translation>
    </message>
    <message>
        <source>Break</source>
        <translation type="vanished">断裂</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="vanished">铅笔</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="vanished">压感</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="vanished">平滑:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="vanished">范围:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="vanished">吸附</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="vanished">&lt;定制&gt;</translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="vanished">关闭</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="vanished">线性</translation>
    </message>
    <message>
        <source>In</source>
        <translation type="vanished">内</translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="vanished">外</translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation type="vanished">内&amp;外</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="vanished">低</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="vanished">高</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="vanished">平头</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="vanished">圆头</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="vanished">方头</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="vanished">斜接连接</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="vanished">圆角连接</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="vanished">斜角连接</translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="vanished">中</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation type="vanished">绘制顺序:</translation>
    </message>
    <message>
        <source>Over All</source>
        <translation type="vanished">在最上</translation>
    </message>
    <message>
        <source>Under All</source>
        <translation type="vanished">在最下</translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation type="vanished">按调色板顺序</translation>
    </message>
</context>
<context>
    <name>BrushToolOptionsBox</name>
    <message>
        <source>Preset Name</source>
        <translation>预设名称</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>ControlPointEditorTool</name>
    <message>
        <source>Auto Select Drawing</source>
        <translation>自动选择绘图</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>吸附</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>手绘</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>中</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
</context>
<context>
    <name>ControlPointSelection</name>
    <message>
        <source>Set Linear Control Point</source>
        <translation>设置线性控制点</translation>
    </message>
    <message>
        <source>Set Nonlinear Control Point</source>
        <translation>设置非线性控制点</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation>当前</translation>
    </message>
</context>
<context>
    <name>EditTool</name>
    <message>
        <source>Scale Constraint:</source>
        <translation>缩放设置:</translation>
    </message>
    <message>
        <source>Auto Select Column</source>
        <translation>自动选择列</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>全局关键帧</translation>
    </message>
    <message>
        <source>Lock Center X</source>
        <translation>锁定中心点(左右)</translation>
    </message>
    <message>
        <source>Lock Center Y</source>
        <translation>锁定中心点(上下)</translation>
    </message>
    <message>
        <source>Lock Position X</source>
        <translation>锁定位置(左右)</translation>
    </message>
    <message>
        <source>Lock Position Y</source>
        <translation>锁定位置(上下)</translation>
    </message>
    <message>
        <source>Lock Rotation</source>
        <translation>锁定旋转</translation>
    </message>
    <message>
        <source>Lock Shear H</source>
        <translation>锁定切变(水平)</translation>
    </message>
    <message>
        <source>Lock Shear V</source>
        <translation>锁定切变(垂直)</translation>
    </message>
    <message>
        <source>Lock Scale H</source>
        <translation>锁定缩放(水平)</translation>
    </message>
    <message>
        <source>Lock Scale V</source>
        <translation>锁定缩放(垂直)</translation>
    </message>
    <message>
        <source>Lock Global Scale</source>
        <translation>锁定缩放(全局)</translation>
    </message>
    <message>
        <source>X and Y Positions</source>
        <translation>左右和上下位置</translation>
    </message>
    <message>
        <source>Z Position</source>
        <translation>纵深位置</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>堆栈顺序</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>旋转</translation>
    </message>
    <message>
        <source>Global Scale</source>
        <translation>全局缩放</translation>
    </message>
    <message>
        <source>Horizontal and Vertical Scale</source>
        <translation>水平和垂直缩放</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>切变</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>中心位置</translation>
    </message>
    <message>
        <source>Active Axis</source>
        <translation>当前轴</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>A/R</source>
        <translation>A/R</translation>
    </message>
    <message>
        <source>Mass</source>
        <translation>大量</translation>
    </message>
    <message>
        <source>Column</source>
        <translation>列</translation>
    </message>
    <message>
        <source>Pegbar</source>
        <translation>定位尺</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>中心点</translation>
    </message>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
</context>
<context>
    <name>EraserTool</name>
    <message>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬度:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>模式:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>选择性</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>反转</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>帧范围</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>铅笔模式</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>正常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>手绘</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>折线</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>线</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>线和区域</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>自动分段</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation>线性</translation>
    </message>
    <message>
        <source>Ease In</source>
        <translation>渐入</translation>
    </message>
    <message>
        <source>Ease Out</source>
        <translation>渐出</translation>
    </message>
    <message>
        <source>Ease In/Out</source>
        <translation>渐入/出</translation>
    </message>
</context>
<context>
    <name>FillTool</name>
    <message>
        <source>Frame Range</source>
        <translation>帧范围</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>选择性</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>模式:</translation>
    </message>
    <message>
        <source>Onion Skin</source>
        <translation>洋葱皮</translation>
    </message>
    <message>
        <source>Fill Depth</source>
        <translation>填充深度</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>自动分段</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>线</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Lines &amp;&amp; Areas</source>
        <translation type="vanished">线和区域</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>正常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>手绘</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>折线</translation>
    </message>
    <message>
        <source>Autopaint Lines</source>
        <translation>自动填充线</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>线和区域</translation>
    </message>
    <message>
        <source>Maximum Gap</source>
        <translation>最大间隙</translation>
    </message>
</context>
<context>
    <name>FingerTool</name>
    <message>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>反转</translation>
    </message>
</context>
<context>
    <name>FullColorBrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">粗细</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">压力灵敏度</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="vanished">不透明度:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬度:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>预设:</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>压感</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>不透明度</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>橡皮差</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>锁定透明度</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;定制&gt;</translation>
    </message>
</context>
<context>
    <name>FullColorEraserTool</name>
    <message>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>不透明度:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬度:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>反转</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>帧范围</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>正常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>手绘</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>折线</translation>
    </message>
</context>
<context>
    <name>FullColorFillTool</name>
    <message>
        <source>Fill Depth</source>
        <translation>填充深度</translation>
    </message>
</context>
<context>
    <name>HandToolOptionsBox</name>
    <message>
        <source>Reset Position</source>
        <translation>重置位置</translation>
    </message>
</context>
<context>
    <name>HookTool</name>
    <message>
        <source>Snap</source>
        <translation>吸附</translation>
    </message>
</context>
<context>
    <name>MagnetTool</name>
    <message>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
</context>
<context>
    <name>PaintBrushTool</name>
    <message>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>模式:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>选择性</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>线</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>线和区域</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>锁定透明度</translation>
    </message>
</context>
<context>
    <name>PinchTool</name>
    <message>
        <source>Size:</source>
        <translation>作用范围：</translation>
    </message>
    <message>
        <source>Corner:</source>
        <translation>拐角:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
</context>
<context>
    <name>PlasticTool</name>
    <message>
        <source>Build Skeleton</source>
        <translation>制作骨架</translation>
    </message>
    <message>
        <source>Paint Rigid</source>
        <translation>绘画刚性</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>动画</translation>
    </message>
    <message>
        <source>Rigid</source>
        <translation>刚性</translation>
    </message>
    <message>
        <source>Flex</source>
        <translation>弹性</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>模式:</translation>
    </message>
    <message>
        <source>Vertex Name:</source>
        <translation>顶点名:</translation>
    </message>
    <message>
        <source>Allow Stretching</source>
        <translation>允许伸缩</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>粗细</translation>
    </message>
    <message>
        <source>Keep Distance</source>
        <translation>保持距离</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>全局关键帧</translation>
    </message>
    <message>
        <source>A group of skeletons already exists for current column. Replacing it will also substitute any existing vertex animation.

Do you want to continue?</source>
        <translation>当前列已经包含了一个骨架组。替换它会换掉全部现有的顶点动画。

你要继续吗？</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Copy Skeleton</source>
        <translation>拷贝骨架</translation>
    </message>
    <message>
        <source>Paste Skeleton</source>
        <translation>粘贴骨架</translation>
    </message>
    <message>
        <source>Delete Vertex</source>
        <translation>删除顶点</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>设置关键帧</translation>
    </message>
    <message>
        <source>Set Rest Key</source>
        <translation>设置休止关键帧</translation>
    </message>
    <message>
        <source>Set Global Key</source>
        <translation>设置全局关键帧</translation>
    </message>
    <message>
        <source>Set Global Rest Key</source>
        <translation>设置全局休止关键帧</translation>
    </message>
    <message>
        <source>Show Mesh</source>
        <translation>显示网格</translation>
    </message>
    <message>
        <source>Show Rigidity</source>
        <translation>显示刚性</translation>
    </message>
    <message>
        <source>Show SO</source>
        <translation>显示堆栈顺序</translation>
    </message>
    <message>
        <source>Show Skeleton Onion Skin</source>
        <translation>显示骨架洋葱皮</translation>
    </message>
    <message>
        <source>The previous vertex name will be discarded, and all associated keys will be lost.

Do you want to proceed?</source>
        <translation>之前的顶点名称会被放弃，所有关联的关键帧也会丢失。

你要继续吗？</translation>
    </message>
    <message>
        <source>Edit Mesh</source>
        <translation>编辑网格</translation>
    </message>
    <message>
        <source>Snap To Mesh</source>
        <translation>吸附网格</translation>
    </message>
    <message>
        <source>Angle Bounds</source>
        <translation>角度限制范围</translation>
    </message>
    <message>
        <source>Swap Edge</source>
        <translation>交换边缘</translation>
    </message>
    <message>
        <source>Collapse Edge</source>
        <translation>折叠边缘</translation>
    </message>
    <message>
        <source>Split Edge</source>
        <translation>拆分边缘</translation>
    </message>
    <message>
        <source>Cut Mesh</source>
        <translation>剪切网格</translation>
    </message>
</context>
<context>
    <name>PlasticToolOptionsBox</name>
    <message>
        <source>Create Mesh</source>
        <translation>创建网格</translation>
    </message>
    <message>
        <source>Skeleton:</source>
        <translation>骨架:</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>堆栈顺序</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
</context>
<context>
    <name>PrimitiveParam</name>
    <message>
        <source>Shape:</source>
        <translation>形状:</translation>
    </message>
    <message>
        <source>Thickness:</source>
        <translation>粗细:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>不透明度:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬度:</translation>
    </message>
    <message>
        <source>Polygon Sides:</source>
        <translation>多边形边数:</translation>
    </message>
    <message>
        <source>Auto Group</source>
        <translation>自动成组</translation>
    </message>
    <message>
        <source>Auto Fill</source>
        <translation>自动填充</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>选择性</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>铅笔模式</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>端点</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>斜角比例:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>吸附</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>圆</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>椭圆</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>线</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>折线</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>弧</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>多边形</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>平头</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>圆头</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>方头</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>斜接连接</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>圆角连接</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>斜角连接</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>中</translation>
    </message>
    <message>
        <source>MultiArc</source>
        <translation>多段弧形</translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation>平滑</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>旋转</translation>
    </message>
</context>
<context>
    <name>PumpTool</name>
    <message>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>精度:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Min:</source>
        <translation>最小:</translation>
    </message>
    <message>
        <source>Max:</source>
        <translation>最大:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>The copied selection cannot be pasted in the current drawing.</source>
        <translation>无法将拷贝的选区粘贴到当前图像。</translation>
    </message>
    <message>
        <source>The current column is locked.</source>
        <translation>当前列被锁定。</translation>
    </message>
    <message>
        <source>The current column is not visible in Camera Stand.</source>
        <translation type="vanished">当前列在摄影机位中不可见。</translation>
    </message>
    <message>
        <source>It is not possible to edit the audio column.</source>
        <translation>无法编辑音频列。</translation>
    </message>
    <message>
        <source>It is not possible to edit the Magpie column.</source>
        <translation type="vanished">无法编辑 MAGPIE 列。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Level column.</source>
        <translation>当前工具不能用在层级列上。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh column.</source>
        <translation>当前工具不能用在网格列上。</translation>
    </message>
    <message>
        <source>The current tool cannot be used in Level Strip mode.</source>
        <translation>当前工具不能用于层级条模式。</translation>
    </message>
    <message>
        <source>The current tool cannot be used to edit a motion path.</source>
        <translation>当前工具不能用来编辑运动路径。</translation>
    </message>
    <message>
        <source>The current level is not editable.</source>
        <translation>当前层级是不可编辑的。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Vector Level.</source>
        <translation>当前工具不能用在矢量层级上。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Toonz Level.</source>
        <translation>当前工具不能用在 Toonz 层级上。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Raster Level.</source>
        <translation>当前工具不能用在光栅层级上。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh Level.</source>
        <translation>当前工具不能用在网格层级上。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a mesh-deformed level</source>
        <translation>当前工具不能用在在网格变形层级上</translation>
    </message>
    <message>
        <source>The current frame is locked: any editing is forbidden.</source>
        <translation>当前帧已经被锁定: 禁止所有编辑。</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <source>Move Center</source>
        <translation>移动中心</translation>
    </message>
    <message>
        <source>RGB Picker (R%1, G%2, B%3)</source>
        <translation>RGB 拾色器 (R%1, G%2, B%3)</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>成组</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>解组</translation>
    </message>
    <message>
        <source>Move Group</source>
        <translation>移动组</translation>
    </message>
    <message>
        <source>Modify Fx Gadget  </source>
        <translation>修改特效小工具  </translation>
    </message>
    <message>
        <source>%1   Level : %2  Frame : %3</source>
        <translation>%1   层级 : %2  帧 : %3</translation>
    </message>
    <message>
        <source>Modify Stroke Tool</source>
        <translation>修改描边工具</translation>
    </message>
    <message>
        <source>Modify Spline</source>
        <translation>修改样条线</translation>
    </message>
    <message>
        <source>Deform Raster</source>
        <translation>变形光栅图</translation>
    </message>
    <message>
        <source>Transform Raster</source>
        <translation>变换光栅图</translation>
    </message>
    <message>
        <source>Set Save Box : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</source>
        <translation>设置保存框 : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</translation>
    </message>
    <message>
        <source>The current column is hidden.</source>
        <translation>当前列被隐藏。</translation>
    </message>
    <message>
        <source>Note columns can only be edited in the xsheet or timeline.</source>
        <translation>注意列只能在摄影表或者时间轴上编辑。</translation>
    </message>
    <message>
        <source> to Front</source>
        <translation> 到最前</translation>
    </message>
    <message>
        <source> to Forward</source>
        <translation> 向前</translation>
    </message>
    <message>
        <source> to Back</source>
        <translation> 到最后</translation>
    </message>
    <message>
        <source> to Backward</source>
        <translation> 向后</translation>
    </message>
    <message>
        <source>The selection cannot be updated. It is not editable.</source>
        <translation>所选择的不能被更新。它不是可编辑的。</translation>
    </message>
    <message>
        <source>The selection cannot be deleted. It is not editable.</source>
        <translation>所选择的不能被删除。它不是可编辑的。</translation>
    </message>
    <message>
        <source>The selection cannot be pasted. It is not editable.</source>
        <translation>所选择的不能被粘贴。它不是可编辑的。</translation>
    </message>
    <message>
        <source>The selection cannot be grouped. It is not editable.</source>
        <translation>所选择的不能被成组。它不是可编辑的。</translation>
    </message>
    <message>
        <source>The selection cannot be entered. It is not editable.</source>
        <translation>所选择的不能被进入。它不是可编辑的。</translation>
    </message>
    <message>
        <source>The selection cannot be ungrouped. It is not editable.</source>
        <translation>所选择的不能被取消群组。它不是可编辑的。</translation>
    </message>
    <message>
        <source>The selection cannot be moved. It is not editable.</source>
        <translation>所选择的不能被移动。它不是可编辑的。</translation>
    </message>
    <message>
        <source>Snap At Intersection</source>
        <translation>吸附在交点</translation>
    </message>
</context>
<context>
    <name>RGBPickerTool</name>
    <message>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation>拾取光标位置颜色</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>正常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>手绘</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>折线</translation>
    </message>
</context>
<context>
    <name>RGBPickerToolOptionsBox</name>
    <message>
        <source>Pick Screen</source>
        <translation>屏幕拾色</translation>
    </message>
</context>
<context>
    <name>RasterSelectionTool</name>
    <message>
        <source>No Antialiasing</source>
        <translation>不作抗锯齿处理</translation>
    </message>
    <message>
        <source>Modify Savebox</source>
        <translation>修改保险框</translation>
    </message>
</context>
<context>
    <name>RasterTapeTool</name>
    <message>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translation>距离:</translation>
    </message>
    <message>
        <source>Style Index:</source>
        <translation>样式索引:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>不透明度:</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>帧范围</translation>
    </message>
    <message>
        <source>Angle:</source>
        <translation>角度:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>正常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>手绘</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>折线</translation>
    </message>
    <message>
        <source>current</source>
        <translation>当前</translation>
    </message>
</context>
<context>
    <name>RotateTool</name>
    <message>
        <source>Rotate On Camera Center</source>
        <translation>以相机中心旋转</translation>
    </message>
</context>
<context>
    <name>RotateToolOptionsBox</name>
    <message>
        <source>Reset Rotation</source>
        <translation>重置旋转</translation>
    </message>
</context>
<context>
    <name>RulerToolOptionsBox</name>
    <message>
        <source>X:</source>
        <comment>ruler tool option</comment>
        <translation>横坐标:</translation>
    </message>
    <message>
        <source>Y:</source>
        <comment>ruler tool option</comment>
        <translation>纵坐标:</translation>
    </message>
    <message>
        <source>W:</source>
        <comment>ruler tool option</comment>
        <translation>宽度:</translation>
    </message>
    <message>
        <source>H:</source>
        <comment>ruler tool option</comment>
        <translation>高度:</translation>
    </message>
    <message>
        <source>A:</source>
        <comment>ruler tool option</comment>
        <translation>角度:</translation>
    </message>
    <message>
        <source>L:</source>
        <comment>ruler tool option</comment>
        <translation>长度:</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>手绘</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>折线</translation>
    </message>
</context>
<context>
    <name>SelectionToolOptionsBox</name>
    <message>
        <source>H:</source>
        <translation>水平:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>垂直:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>旋转</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>左右:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>上下:</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>粗细</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>保持长宽比</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
</context>
<context>
    <name>ShiftTraceToolOptionBox</name>
    <message>
        <source>Reset Previous</source>
        <translation>重置前面的</translation>
    </message>
    <message>
        <source>Reset Following</source>
        <translation>重置后面的</translation>
    </message>
    <message>
        <source>Previous Drawing</source>
        <translation>前面的绘图</translation>
    </message>
    <message>
        <source>Following Drawing</source>
        <translation>后面的绘图</translation>
    </message>
</context>
<context>
    <name>SkeletonTool</name>
    <message>
        <source>Global Key</source>
        <translation>全局关键帧</translation>
    </message>
    <message>
        <source>Show Only Active Skeleton</source>
        <translation>仅显示活动的骨架</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>模式:</translation>
    </message>
    <message>
        <source>Reset Pinned Center</source>
        <translation>重置固定中心</translation>
    </message>
    <message>
        <source>Build Skeleton</source>
        <translation>制作骨架</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>动画</translation>
    </message>
    <message>
        <source>Inverse Kinematics</source>
        <translation>反向运动学</translation>
    </message>
</context>
<context>
    <name>StylePickerTool</name>
    <message>
        <source>No current level.</source>
        <translation>没有当前层级。</translation>
    </message>
    <message>
        <source>Current level has no available palette.</source>
        <translation>当前层级没有可用色板。</translation>
    </message>
    <message>
        <source>Palette must have more than one palette to be organized.</source>
        <translation>必须要多个色板才能被组织。</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>模式:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation>拾取光标位置颜色</translation>
    </message>
    <message>
        <source>Organize Palette</source>
        <translation>整理调色板</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>线</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>线和区域</translation>
    </message>
</context>
<context>
    <name>StylePickerToolOptionsBox</name>
    <message>
        <source>With this option being activated, the picked style will be
moved to the end of the first page of the palette.</source>
        <translation>打开这个选项，选中的样式将被移到色板第一页的最后。</translation>
    </message>
</context>
<context>
    <name>ToonzRasterBrushTool</name>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬度:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation>平滑:</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation>绘制顺序:</translation>
    </message>
    <message>
        <source>Over All</source>
        <translation>在最上</translation>
    </message>
    <message>
        <source>Under All</source>
        <translation>在最下</translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation>按调色板顺序</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>预设:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;定制&gt;</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>铅笔</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>压感</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>锁定透明度</translation>
    </message>
</context>
<context>
    <name>ToonzVectorBrushTool</name>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>精度:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation>平滑:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>预设:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;定制&gt;</translation>
    </message>
    <message>
        <source>Break</source>
        <translation>断裂</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>压感</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>端点</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>斜接比例:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>范围:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>吸附</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation>线性</translation>
    </message>
    <message>
        <source>In</source>
        <translation>内</translation>
    </message>
    <message>
        <source>Out</source>
        <translation>外</translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation>内&amp;外</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>中</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>平头</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>圆头</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>方头</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>斜接连接</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>圆角连接</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>斜角连接</translation>
    </message>
</context>
<context>
    <name>TrackerTool</name>
    <message>
        <source>Width:</source>
        <translation>宽度:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>高度:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
</context>
<context>
    <name>TypeTool</name>
    <message>
        <source>Font:</source>
        <translation>字体:</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>样式:</translation>
    </message>
    <message>
        <source>Vertical Orientation</source>
        <translation>直排</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
</context>
<context>
    <name>VectorSelectionTool</name>
    <message>
        <source>Mode:</source>
        <translation>模式:</translation>
    </message>
    <message>
        <source>Preserve Thickness</source>
        <translation>保持粗细</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>端点</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>斜接比例:</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>标准</translation>
    </message>
    <message>
        <source>Selected Frames</source>
        <translation>已选帧</translation>
    </message>
    <message>
        <source>Whole Level</source>
        <translation>整个层级</translation>
    </message>
    <message>
        <source>Same Style</source>
        <translation>相同类型</translation>
    </message>
    <message>
        <source>Same Style on Selected Frames</source>
        <translation>已选帧中的同类型</translation>
    </message>
    <message>
        <source>Same Style on Whole Level</source>
        <translation>整个层级中的同类型</translation>
    </message>
    <message>
        <source>Boundary Strokes</source>
        <translation>边界描边</translation>
    </message>
    <message>
        <source>Boundaries on Selected Frames</source>
        <translation>所选帧的边界</translation>
    </message>
    <message>
        <source>Boundaries on Whole Level</source>
        <translation>整个层级的边界</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>平头</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>圆头</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>方头</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>斜接连接</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>圆角连接</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>斜角连接</translation>
    </message>
    <message>
        <source>Include Intersection</source>
        <translation>包括交点</translation>
    </message>
</context>
<context>
    <name>VectorTapeTool</name>
    <message>
        <source>Smooth</source>
        <translation>平滑</translation>
    </message>
    <message>
        <source>Join Vectors</source>
        <translation>连接矢量</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>模式:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <source>Endpoint to Endpoint</source>
        <translation>端点到端点</translation>
    </message>
    <message>
        <source>Endpoint to Line</source>
        <translation>端点到线</translation>
    </message>
    <message>
        <source>Line to Line</source>
        <translation>线到线</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>正常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>矩形</translation>
    </message>
</context>
<context>
    <name>ZoomToolOptionsBox</name>
    <message>
        <source>Reset Zoom</source>
        <translation>重置缩放</translation>
    </message>
</context>
</TS>
